@@ -18,16 +18,16 @@
 
 #include "incrementlistviewitem.h"
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <tqdir.h>
-#include <klistview.h>
+#include <tdelistview.h>
 
-IncrementListViewItem::IncrementListViewItem(KListView *parent,TQDateTime date): TQListViewItem (parent) 
+IncrementListViewItem::IncrementListViewItem(TDEListView *parent,TQDateTime date): TQListViewItem (parent) 
 { 
 	setDate(date);
 }
 
-IncrementListViewItem::IncrementListViewItem(KListView *parent,TQListViewItem *item,TQDateTime date): TQListViewItem (parent,item) 
+IncrementListViewItem::IncrementListViewItem(TDEListView *parent,TQListViewItem *item,TQDateTime date): TQListViewItem (parent,item) 
 { 
 	setDate(date);
 }
